/******************************************************************************\
* Copyright (C) 2005 by Relcom Kft.
* All rights reserved.
*------------------------------------------------------------------------------
* PROJECT.......... Board Support Library for pcDSP6
* VERSION.......... 1.0
* COMPILER......... Code Composer Studio 3.0
*------------------------------------------------------------------------------
* CONTENT.......... Digital Potentiometer module of pcDSP6
* FILENAME......... bsl_digpot.h
* LAST MODIFIED AT. 11/04/2005
\******************************************************************************/

#ifndef _BSL_DIGPOT_H_
#define _BSL_DIGPOT_H_

#include <bsl.h>
#include <bsl_x9241drv.h>


/******************************************************************************\
* scope and inline control macros
\******************************************************************************/

#ifdef	__cplusplus
	#define	BSLAPI extern "C" far 
#else
	#define	BSLAPI extern far
#endif

#undef	USEDEFS
#undef	IDECL
#undef	IDEF

#ifdef	_BSL_DIGPOT_MOD_
	#define IDECL BSLAPI
	#define USEDEFS
	#define IDEF
#else
	#ifdef	_INLINE
		#define	IDECL static inline
		#define	USEDEFS
		#define	IDEF  static inline
	#else
		#define	IDECL BSLAPI
	#endif
#endif


/******************************************************************************\
* global macro declarations
\******************************************************************************/


/******************************************************************************\
* global typedef declarations
\******************************************************************************/

//! I2C Device IDs for Base-band Analog Inputs/Outputs
typedef enum {
	DIGPOT_DEV_BBAIO1,	//!< I2C Device ID for Base-band Analog Input/Output 1
	DIGPOT_DEV_BBAIO2	//!< I2C Device ID for Base-band Analog Input/Output 2
} E_DIGPOT_DEV;

//! IDs for selecting Base-band Analog Inputs/Outputs
typedef enum {
	DIGPOT_BBAIO1,		//!< ID for Base-band Analog Input/Output 1
	DIGPOT_BBAIO2		//!< ID for Base-band Analog Input/Output 2
} E_DIGPOT_BBAIO;

//! Potentiometer IDs in a 4-pot device
typedef enum {
	DIGPOT_POT_INPUT_GAIN_OFFSET,		//!< Input PGA, GAIN offset
	DIGPOT_POT_INPUT_SC_FILTER_OFFSET,	//!< Input SC filter offset for FAIN
	DIGPOT_POT_INPUT_GAIN,				//!< Input Gain (1..10)
	DIGPOT_POT_OUTPUT_SC_FILTER_OFFSET	//!< Output SC filter offset for FAOUT
} E_DIGPOT_POT;

//! Non-volatile memory locations within a digital potentiometer device to
//! save the values of the WCRs (Wiper Counter Register).
typedef enum {
	DIGPOT_MEM_0,
	DIGPOT_MEM_AT_POWER_UP	= DIGPOT_MEM_0,
	DIGPOT_MEM_1,
	DIGPOT_MEM_2,
	DIGPOT_MEM_3
} E_DIGPOT_MEM;


/******************************************************************************\
* global variable declarations
\******************************************************************************/


/******************************************************************************\
* global function declarations
\******************************************************************************/

//- ----------------------------------------------------------------------------
//! \brief	Waits for the last command to complete.
//!
//!	Waits for the last command to complete.
//!
//!	\return	TRUE, if the digital potentiometer device is done within 10 msec to
//!			receive a new command. Otherwise, FALSE.
//- ----------------------------------------------------------------------------
BSLAPI Uint32 DIGPOT_WaitForCommandToComplete(
	Uint32 SelectBBAIO);	//!< Select the BBAIO to be used. [DIGPOT_BBAIO*]


/******************************************************************************\
* inline function declarations
\******************************************************************************/

//- ----------------------------------------------------------------------------
//! \brief	Checks whether the given digital potentiometer device is ready to
//!			receive a new command, or not.
//!
//!	Checks whether the given digital potentiometer device is ready to receive a
//!			new command, or not.
//!
//!	\return	TRUE, if the digital potentiometer device is ready to receive a new
//!			command. Otherwise, FALSE (the device is busy).
//- ----------------------------------------------------------------------------
IDECL Uint32 DIGPOT_IsItReady(
	Uint32 SelectBBAIO);	//!< Select the BBAIO to be used. [DIGPOT_BBAIO*]

//- ----------------------------------------------------------------------------
//! \brief	Provides the currently set value of the given potentiometer.
//!
//!	Provides the currently set value of the given potentiometer.
//!
//!	\return	TRUE, if the command was successfully performed.
//!			FALSE can be returned, if the digital potentiometer device is busy.
//- ----------------------------------------------------------------------------
IDECL Uint32 DIGPOT_Get(
	Uint32 SelectBBAIO,		//!< Select the BBAIO to be used. [DIGPOT_BBAIO*]
	Uint32 Potentiometer,	//!< Select the potentiometer to be saved. [DIGPOT_POT_*]
	Uint32 *pValue);		//!< Pointer to variable to receive the currently set value.

//- ----------------------------------------------------------------------------
//! \brief	Set the value of the given potentiometer.
//!
//!	Set the value of the given potentiometer.
//!
//!	\return	TRUE, if the command was successfully performed.
//!			FALSE can be returned, if the digital potentiometer device is busy.
//- ----------------------------------------------------------------------------
IDECL Uint32 DIGPOT_Set(
	Uint32 SelectBBAIO,		//!< Select the BBAIO to be used. [DIGPOT_BBAIO*]
	Uint32 Potentiometer,	//!< Select the potentiometer to be saved. [DIGPOT_POT_*]
	Uint32 NewValue);		//!< The new value to be set.

//- ----------------------------------------------------------------------------
//! \brief	Sets the value of the given potentiometer, loading its saved value
//!			from the given non-volatile memory cell.
//!
//!	Sets the value of the given potentiometer, loading its saved value from the
//!	given non-volatile memory cell.
//!
//!	\return	TRUE, if the command was successfully performed.
//!			FALSE can be returned, if the digital potentiometer device is busy.
//- ----------------------------------------------------------------------------
IDECL Uint32 DIGPOT_Load(
	Uint32 SelectBBAIO,		//!< Select the BBAIO to be used. [DIGPOT_BBAIO*]
	Uint32 Potentiometer,	//!< Select the potentiometer to be loaded. [DIGPOT_POT_*]
	Uint32 MemoryLocation);	//!< Select the memory from where the pot. loaded. [DIGPOT_MEM_*]

//- ----------------------------------------------------------------------------
//! \brief	Saves the current value of the given potentiometer to its given
//!			non-volatile memory cell.
//!
//!	Saves the current value of the given potentiometer to its given non-volatile
//!	memory cell.
//!
//!	\return	TRUE, if the command was successfully performed.
//!			FALSE can be returned, if the digital potentiometer device is busy.
//- ----------------------------------------------------------------------------
IDECL Uint32 DIGPOT_Save(
	Uint32 SelectBBAIO,		//!< Select the BBAIO to be used. [DIGPOT_BBAIO*]
	Uint32 Potentiometer,	//!< Select the potentiometer to be saved. [DIGPOT_POT_*]
	Uint32 MemoryLocation,	//!< Select the memory to where the pot. saved. [DIGPOT_MEM_*]
	Uint32 WaitForComplete);//!< Set TRUE to wait for the command to complete

//- ----------------------------------------------------------------------------
//! \brief	Sets all the potentiometers, loading their saved values from the
//!			given non-volatile memory cells.
//!
//!	Sets all the potentiometers, loading their saved values from the given
//! non-volatile memory cells.
//!
//!	\return	TRUE, if the command was successfully performed.
//!			FALSE can be returned, if the digital potentiometer device is busy.
//- ----------------------------------------------------------------------------
IDECL Uint32 DIGPOT_LoadAll(
	Uint32 SelectBBAIO,		//!< Select the BBAIO to be used. [DIGPOT_BBAIO*]
	Uint32 MemoryLocation);	//!< Select the memory from where the pot. loaded. [DIGPOT_MEM_*]

//- ----------------------------------------------------------------------------
//! \brief	Saves the current values of all the potentiometers to the given
//!			non-volatile memory cells.
//!
//!	Saves the current values of all the potentiometers to the give non-volatile
//! memory cells.
//!
//!	\return	TRUE, if the command was successfully performed.
//!			FALSE can be returned, if the digital potentiometer device is busy.
//- ----------------------------------------------------------------------------
IDECL Uint32 DIGPOT_SaveAll(
	Uint32 SelectBBAIO,		//!< Select the BBAIO to be used. [DIGPOT_BBAIO*]
	Uint32 MemoryLocation,	//!< Select the memory to where the pot. saved. [DIGPOT_MEM_*]
	Uint32 WaitForComplete);//!< Set TRUE to wait for the command to complete

//- ----------------------------------------------------------------------------
//! \brief	Reads the given non-volatile memory cell of the given potentiometer.
//!
//!	Reads the given non-volatile memory cell of the given potentiometer.
//!
//!	\return	TRUE, if the command was successfully performed.
//!			FALSE can be returned, if the digital potentiometer device is busy.
//- ----------------------------------------------------------------------------
IDECL Uint32 DIGPOT_ReadMemory(
	Uint32 SelectBBAIO,		//!< Select the BBAIO to be used. [DIGPOT_BBAIO*]
	Uint32 Potentiometer,	//!< Select the potentiometer to be saved. [DIGPOT_POT_*]
	Uint32 MemoryLocation,	//!< Select the memory to be written. [DIGPOT_MEM_*]
	Uint32 *pValue);		//!< Pointer to variable to receive the currently set value.

//- ----------------------------------------------------------------------------
//! \brief	Writes the given non-volatile memory cell of the given
//!			potentiometer.
//!
//!	Writes the given non-volatile memory cell of the given potentiometer.
//!
//!	\return	TRUE, if the command was successfully performed.
//!			FALSE can be returned, if the digital potentiometer device is busy.
//- ----------------------------------------------------------------------------
IDECL Uint32 DIGPOT_WriteMemory(
	Uint32 SelectBBAIO,		//!< Select the BBAIO to be used. [DIGPOT_BBAIO*]
	Uint32 Potentiometer,	//!< Select the potentiometer to be used. [DIGPOT_POT_*]
	Uint32 MemoryLocation,	//!< Select the memory to be written. [DIGPOT_MEM_*]
	Uint32 NewValue,		//!< The new value to be set.
	Uint32 WaitForComplete);//!< Set TRUE to wait for the command to complete


/******************************************************************************\
* inline function definitions
\******************************************************************************/
#ifdef USEDEFS

IDEF Uint32 DIGPOT_IsItReady(
	Uint32 SelectBBAIO)	//!< Select the BBAIO to be used. [DIGPOT_BBAIO*]
{
	return X9241DRV_CHECK_COMMAND_COMPLETED(SelectBBAIO);
}

IDEF Uint32 DIGPOT_Get(
	Uint32 SelectBBAIO,		//!< Select the BBAIO to be used. [DIGPOT_BBAIO*]
	Uint32 Potentiometer,	//!< Select the potentiometer to be saved. [DIGPOT_POT_*]
	Uint32 *pValue)			//!< Pointer to variable to receive the currently set value.
{
	return( X9241DRV_READ_WCR(SelectBBAIO, Potentiometer, pValue) == 3 );
}

IDEF Uint32 DIGPOT_Set(
	Uint32 SelectBBAIO,		//!< Select the BBAIO to be used. [DIGPOT_BBAIO*]
	Uint32 Potentiometer,	//!< Select the potentiometer to be saved. [DIGPOT_POT_*]
	Uint32 NewValue)		//!< The new value to be set.
{
	return( X9241DRV_WRITE_WCR(SelectBBAIO, Potentiometer, NewValue) == 3 );
}

IDEF Uint32 DIGPOT_Load(
	Uint32 SelectBBAIO,		//!< Select the BBAIO to be used. [DIGPOT_BBAIO*]
	Uint32 Potentiometer,	//!< Select the potentiometer to be loaded. [DIGPOT_POT_*]
	Uint32 MemoryLocation)	//!< Select the memory from where the pot. loaded. [DIGPOT_MEM_*]
{
	return( X9241DRV_XFR_DATA_REG_TO_WCR(SelectBBAIO, Potentiometer, MemoryLocation) == 2 );
}

IDEF Uint32 DIGPOT_Save(
	Uint32 SelectBBAIO,		//!< Select the BBAIO to be used. [DIGPOT_BBAIO*]
	Uint32 Potentiometer,	//!< Select the potentiometer to be saved. [DIGPOT_POT_*]
	Uint32 MemoryLocation,	//!< Select the memory to where the pot. saved. [DIGPOT_MEM_*]
	Uint32 WaitForComplete)	//!< Set TRUE to wait for the command to complete
{
	if( X9241DRV_XFR_WCR_TO_DATA_REG(SelectBBAIO, Potentiometer, MemoryLocation) != 2 )
	{
		// Writing the non-volatile memory failed.
		return 0;
	}
	
	if( WaitForComplete )
	{
		return DIGPOT_WaitForCommandToComplete(SelectBBAIO);
	}

	// Command is completed.
	return 1;
}

IDEF Uint32 DIGPOT_LoadAll(
	Uint32 SelectBBAIO,		//!< Select the BBAIO to be used. [DIGPOT_BBAIO*]
	Uint32 MemoryLocation)	//!< Select the memory from where the pot. loaded. [DIGPOT_MEM_*]
{
	return( X9241DRV_GLOBAL_XFR_DATA_REG_TO_WCR(SelectBBAIO, MemoryLocation) == 2 );
}

IDEF Uint32 DIGPOT_SaveAll(
	Uint32 SelectBBAIO,		//!< Select the BBAIO to be used. [DIGPOT_BBAIO*]
	Uint32 MemoryLocation,	//!< Select the memory to where the pot. saved. [DIGPOT_MEM_*]
	Uint32 WaitForComplete)	//!< Set TRUE to wait for the command to complete
{
	if( X9241DRV_GLOBAL_XFR_WCR_TO_DATA_REG(SelectBBAIO, MemoryLocation) != 2 )
	{
		// Writing the non-volatile memories failed.
		return 0;
	}
	
	if( WaitForComplete )
	{
		return DIGPOT_WaitForCommandToComplete(SelectBBAIO);
	}

	// Command is completed.
	return 1;
}

IDEF Uint32 DIGPOT_ReadMemory(
	Uint32 SelectBBAIO,		//!< Select the BBAIO to be used. [DIGPOT_BBAIO*]
	Uint32 Potentiometer,	//!< Select the potentiometer to be saved. [DIGPOT_POT_*]
	Uint32 MemoryLocation,	//!< Select the memory to be written. [DIGPOT_MEM_*]
	Uint32 *pValue)			//!< Pointer to variable to receive the currently set value.
{
	return( X9241DRV_READ_DATA_REG(
		SelectBBAIO, Potentiometer, MemoryLocation, pValue) == 3 );
}

IDEF Uint32 DIGPOT_WriteMemory(
	Uint32 SelectBBAIO,		//!< Select the BBAIO to be used. [DIGPOT_BBAIO*]
	Uint32 Potentiometer,	//!< Select the potentiometer to be used. [DIGPOT_POT_*]
	Uint32 MemoryLocation,	//!< Select the memory to be written. [DIGPOT_MEM_*]
	Uint32 NewValue,		//!< The new value to be set.
	Uint32 WaitForComplete)	//!< Set TRUE to wait for the command to complete
{
	if( X9241DRV_WRITE_DATA_REG(
		SelectBBAIO, Potentiometer, MemoryLocation, NewValue) != 3 )
	{
		// Writing the non-volatile memories failed.
		return 0;
	}
	
	if( WaitForComplete )
	{
		return DIGPOT_WaitForCommandToComplete(SelectBBAIO);
	}

	// Command is completed.
	return 1;
}

/*----------------------------------------------------------------------------*/
#endif /* USEDEFS */


#endif /* _BSL_DIGPOT_H_ */
/******************************************************************************\
* End of bsl_digpot.h
\******************************************************************************/

