/******************************************************************************\
* Copyright (C) 2005 by Relcom Kft.
* All rights reserved.
*------------------------------------------------------------------------------
* PROJECT.......... Board Support Library for pcDSP6
* VERSION.......... 1.0
* COMPILER......... Code Composer Studio 3.0
*------------------------------------------------------------------------------
* CONTENT.......... I2C Driver for pcDSP6
* FILENAME......... bsl_i2cdrv.h
* LAST MODIFIED AT. 11/04/2005
\******************************************************************************/

#ifndef _BSL_I2CDRV_H_
#define _BSL_I2CDRV_H_

#include <bsl.h>

/******************************************************************************\
* scope and inline control macros
\******************************************************************************/
#ifdef	__cplusplus
	#define	BSLAPI extern "C" far 
#else
	#define	BSLAPI extern far
#endif

#undef	USEDEFS
#undef	IDECL
#undef	IDEF

#ifdef	_BSL_I2CDRV_MOD_
	#define IDECL BSLAPI
	#define USEDEFS
	#define IDEF
#else
	#ifdef	_INLINE
		#define	IDECL static inline
		#define	USEDEFS
		#define	IDEF  static inline
	#else
		#define	IDECL BSLAPI
	#endif
#endif


/******************************************************************************\
* global macro declarations
\******************************************************************************/


/******************************************************************************\
* global typedef declarations
\******************************************************************************/


/******************************************************************************\
* global variable declarations
\******************************************************************************/


/******************************************************************************\
* global function declarations
\******************************************************************************/

//- ----------------------------------------------------------------------------
//! \brief	Sets the I2C bus wires in default state.
//!
//!	Sets the I2C bus wires in default state:
//!		1. Output drive is disabled.
//!		2. Clock is low.
//!		3. Data is high.
//!
//!	Note that there is not STOP condition on the bus.
//!
//!	\post	There is 5 us delay to hold the Clock in low and the Data in high.
//!
//!	\return	Void.
//- ----------------------------------------------------------------------------
BSLAPI void I2CDRV_reset(void);

//- ----------------------------------------------------------------------------
//! \brief	Sends a single-byte (Write) instruction.
//!
//! \pre	The Clock is low, the Data is high and the Output drive is disabled
//!			at least 5 us ago.
//!
//!	Sends a single-byte (Write) instruction.
//!
//!	\post	The Clock is low, the Data is high and the Output drive is disabled
//!			at least 5 us ago.
//!
//!	\return	1, if the sent byte was accepted. Otherwise, 0.
//- ----------------------------------------------------------------------------
BSLAPI Uint32 I2CDRV_sendOneByteInstruction_W(
	Uint32 dataByte1);	//!< first byte to be sent

//- ----------------------------------------------------------------------------
//! \brief	Sends a two-byte (Write-Write) instruction.
//!
//! \pre	The Clock is low, the Data is high and the Output drive is disabled
//!			at least 5 us ago.
//!
//!	Sends a two-byte (Write-Write) instruction.
//!
//!	\post	The Clock is low, the Data is high and the Output drive is disabled
//!			at least 5 us ago.
//!
//!	\return	The number of bytes, which has been accepted.
//!	\retval	0		No byte was accepted. (The first was rejected.)
//!	\retval	1		Only the first byte was accepted. The second byte was
//!					rejected.
//!	\retval	2		Both bytes were accepted.
//- ----------------------------------------------------------------------------
BSLAPI Uint32 I2CDRV_sendTwoByteInstruction_WW(
	Uint32 dataByte1,	//!< first byte to be sent
	Uint32 dataByte2);	//!< second byte to be sent

//- ----------------------------------------------------------------------------
//! \brief	Sends a three-byte (Write-Write-Write) instruction.
//!
//! \pre	The Clock is low, the Data is high and the Output drive is disabled
//!			at least 5 us ago.
//!
//!	Sends a three-byte (Write-Write-Write) instruction.
//!
//!	\post	The Clock is low, the Data is high and the Output drive is disabled
//!			at least 5 us ago.
//!
//!	\return	The number of bytes, which has been accepted.
//!	\retval	0		No byte was accepted. (The first was rejected.)
//!	\retval	1		Only the first byte was accepted. The second byte was
//!					rejected.
//!	\retval	2		Only the first two bytes were accepted. The third byte was
//!					rejected.
//!	\retval	3		All the bytes were accepted.
//- ----------------------------------------------------------------------------
BSLAPI Uint32 I2CDRV_sendThreeByteInstruction_WWW(
	Uint32 dataByte1,	//!< first byte to be sent
	Uint32 dataByte2,	//!< second byte to be sent
	Uint32 dataByte3);	//!< third byte to be sent

//- ----------------------------------------------------------------------------
//! \brief	Sends a three-byte (Write-Write-Read) instruction.
//!
//! \pre	The Clock is low, the Data is high and the Output drive is disabled
//!			at least 5 us ago.
//!
//!	Sends a three-byte (Write-Write-Read) instruction.
//!
//!	\post	The Clock is low, the Data is high and the Output drive is disabled
//!			at least 5 us ago.
//!
//!	\return	The number of bytes, which has been accepted.
//!	\retval	0		No byte was accepted. (The first was rejected.)
//!	\retval	1		Only the first byte was accepted. The second byte was
//!					rejected.
//!	\retval	3		Both sent bytes were accepted and a third byte was received.
//- ----------------------------------------------------------------------------
BSLAPI Uint32 I2CDRV_sendThreeByteInstruction_WWR(
	Uint32 dataByte1,	//!< first byte to be sent
	Uint32 dataByte2,	//!< second byte to be sent
	Uint32 *pdataByte3);//!< pointer to the received byte


/******************************************************************************\
* inline function declarations
\******************************************************************************/


/******************************************************************************\
* inline function definitions
\******************************************************************************/
#ifdef USEDEFS

/*----------------------------------------------------------------------------*/
#endif /* USEDEFS */


#endif /* _BSL_I2CDRV_H_ */
/******************************************************************************\
* End of bsl_i2cdrv.h
\******************************************************************************/

