/******************************************************************************\
* Copyright (C) 2005 by Relcom Kft.
* All rights reserved.
*------------------------------------------------------------------------------
* PROJECT.......... Board Support Library for pcDSP6
* VERSION.......... 1.0
* COMPILER......... Code Composer Studio 3.0
*------------------------------------------------------------------------------
* CONTENT.......... X9241 Digital Potentiometer Driver for pcDSP6
* FILENAME......... bsl_x9241drv.h
* LAST MODIFIED AT. 11/04/2005
\******************************************************************************/

#ifndef _BSL_X9241DRV_H_
#define _BSL_X9241DRV_H_

#include <bsl_i2cdrv.h>

/******************************************************************************\
* scope and inline control macros
\******************************************************************************/


/******************************************************************************\
* global macro declarations
\******************************************************************************/

//
// Internally used Service macros
//

//! Provides the Slave Address of the device
#define X9241DRV_SLAVE_ADDRESS( 											\
	DevID)		/*!< ID of the device on the I2C bus */						\
	(((Uint32)0x50)															\
	| (((Uint32)(DevID)) & 0xF))

//! Provides the Instruction Byte for a command
#define X9241DRV_INSTRUCTION(												\
	InstrID,	/*!< ID of Instruction */									\
	PotID,		/*!< ID of potentiometer to be used */						\
	RegID)		/*!< ID of the non-volatile memory register to be used */	\
	((((Uint32)(InstrID)) & 0xF0)											\
	| ((((Uint32)(PotID)) & 3) << 2)										\
	| (((Uint32)(RegID)) & 3))

//
// Macros to generate X9241 commands
//

//- ----------------------------------------------------------------------------
//! \brief	Checks the last command to complete.
//!
//! \pre	The I2C driver keeps the bus wires in their default/reset states.
//!
//!	Checks the last command to complete, performing a single-byte instruction.
//!
//!	The I2CDRV_sendOneByteInstruction_W() is called to perform the command.
//!
//!	\post	The I2C driver keeps the bus wires in their default/reset states.
//!
//!	\return The selected device is ready or busy.
//!	\retval 0		The selected device is still working on the last command.
//!	\retval	1		If the selected device is ready to accept a new command.
//- ----------------------------------------------------------------------------
#define X9241DRV_CHECK_COMMAND_COMPLETED(									\
	DevID)		/*!< ID of the device on the I2C bus */						\
	I2CDRV_sendOneByteInstruction_W( X9241DRV_SLAVE_ADDRESS( DevID ) )

//- ----------------------------------------------------------------------------
//! \brief	Reads the Wiper Counter Register (WCR).
//!
//! \pre	The I2C driver keeps the bus wires in their default/reset states.
//!
//!	Reads the Wiper Counter Register (WCR) of the selected potentiometer from
//!	the addressed device.
//!
//!	The I2CDRV_sendThreeByteInstruction_WWR() is called to perform the command.
//!
//!	\post	The I2C driver keeps the bus wires in their default/reset states.
//!
//!	\return	The number of bytes, which has been accepted.
//!	\retval	0		No byte was accepted. (The first was rejected.)
//!	\retval	1		Only the first byte was accepted. The second byte was
//!					rejected.
//!	\retval	3		Both sent bytes were accepted and a third byte was received.
//- ----------------------------------------------------------------------------
#define X9241DRV_READ_WCR(													\
	DevID,		/*!< ID of the device on the I2C bus */						\
	PotID,		/*!< ID of potentiometer to be used */						\
	pWcrValue)	/*!< The read value of the WCR */							\
	I2CDRV_sendThreeByteInstruction_WWR(									\
		X9241DRV_SLAVE_ADDRESS( DevID ),									\
		X9241DRV_INSTRUCTION( 0x90, PotID, 0 ),								\
		pWcrValue)

//- ----------------------------------------------------------------------------
//! \brief	Writes the Wiper Counter Register (WCR).
//!
//! \pre	The I2C driver keeps the bus wires in their default/reset states.
//!
//!	Writes the Wiper Counter Register (WCR) of the selected potentiometer in the
//!	addressed device.
//!
//!	The I2CDRV_sendThreeByteInstruction_WWW() is called to perform the command.
//!
//!	\post	The I2C driver keeps the bus wires in their default/reset states.
//!
//!	\return	The number of bytes, which has been accepted.
//!	\retval	0		No byte was accepted. (The first was rejected.)
//!	\retval	1		Only the first byte was accepted. The second byte was
//!					rejected.
//!	\retval	2		Only the first two bytes were accepted. The third byte was
//!					rejected.
//!	\retval	3		All the bytes were accepted.
//- ----------------------------------------------------------------------------
#define X9241DRV_WRITE_WCR(													\
	DevID,		/*!< ID of the device on the I2C bus */						\
	PotID,		/*!< ID of potentiometer to be used */						\
	WcrValue)	/*!< WCR value to be written */								\
	I2CDRV_sendThreeByteInstruction_WWW(									\
		X9241DRV_SLAVE_ADDRESS( DevID ),									\
		X9241DRV_INSTRUCTION( 0xA0, PotID, 0 ),								\
		WcrValue)

//- ----------------------------------------------------------------------------
//! \brief	Reads a Data Register (a non-volatile memory cell) of the selected
//!			potentionmeter.
//!
//! \pre	The I2C driver keeps the bus wires in their default/reset states.
//!
//!	Reads a Data Register (a non-volatile memory cell) of the selected
//!	potentionmeter from the addressed device.
//!
//!	The I2CDRV_sendThreeByteInstruction_WWR() is called to perform the command.
//!
//!	\post	The I2C driver keeps the bus wires in their default/reset states.
//!
//!	\return	The number of bytes, which has been accepted.
//!	\retval	0		No byte was accepted. (The first was rejected.)
//!	\retval	1		Only the first byte was accepted. The second byte was
//!					rejected.
//!	\retval	3		Both sent bytes were accepted and a third byte was received.
//- ----------------------------------------------------------------------------
#define X9241DRV_READ_DATA_REG(												\
	DevID,		/*!< ID of the device on the I2C bus */						\
	PotID,		/*!< ID of potentiometer to be used */						\
	RegID,		/*!< ID of the non-volatile memory register to be used */	\
	pRegValue)	/*!< The read value of the data register */					\
	I2CDRV_sendThreeByteInstruction_WWR(									\
		X9241DRV_SLAVE_ADDRESS( DevID ),									\
		X9241DRV_INSTRUCTION( 0xB0, PotID, RegID ),							\
		pRegValue)

//- ----------------------------------------------------------------------------
//! \brief	Writes a Data Register (a non-volatile memory cell) of the selected
//!			potentionmeter.
//!
//! \pre	The I2C driver keeps the bus wires in their default/reset states.
//!
//!	Writes a Data Register (a non-volatile memory cell) of the selected
//!	potentionmeter in the addressed device.
//!
//!	The I2CDRV_sendThreeByteInstruction_WWW() is called to perform the command.
//!
//!	\post	The I2C driver keeps the bus wires in their default/reset states.
//!
//!	\return	The number of bytes, which has been accepted.
//!	\retval	0		No byte was accepted. (The first was rejected.)
//!	\retval	1		Only the first byte was accepted. The second byte was
//!					rejected.
//!	\retval	2		Only the first two bytes were accepted. The third byte was
//!					rejected.
//!	\retval	3		All the bytes were accepted.
//- ----------------------------------------------------------------------------
#define X9241DRV_WRITE_DATA_REG(											\
	DevID,		/*!< ID of the device on the I2C bus */						\
	PotID,		/*!< ID of potentiometer to be used */						\
	RegID,		/*!< ID of the non-volatile memory register to be used */	\
	RegValue)	/*!< Data register value to be written */					\
	I2CDRV_sendThreeByteInstruction_WWW(									\
		X9241DRV_SLAVE_ADDRESS( DevID ),									\
		X9241DRV_INSTRUCTION( 0xC0, PotID, RegID ),							\
		RegValue)

//- ----------------------------------------------------------------------------
//! \brief	Transfers a Data Register (a non-volatile memory cell) to the Wiper
//!			Counter Register (WCR) of a potentiometer.
//!
//! \pre	The I2C driver keeps the bus wires in their default/reset states.
//!
//!	Transfers a Data Register (a non-volatile memory cell) to the Wiper Counter
//!	Register (WCR) of a potentiometer.
//!
//!	The I2CDRV_sendTwoByteInstruction_WW() is called to perform the command.
//!
//!	\post	The I2C driver keeps the bus wires in their default/reset states.
//!
//!	\return	The number of bytes, which has been accepted.
//!	\retval	0		No byte was accepted. (The first was rejected.)
//!	\retval	1		Only the first byte was accepted. The second byte was
//!					rejected.
//!	\retval	2		Both bytes were accepted.
//- ----------------------------------------------------------------------------
#define X9241DRV_XFR_DATA_REG_TO_WCR(										\
	DevID,		/*!< ID of the device on the I2C bus */						\
	PotID,		/*!< ID of potentiometer to be used */						\
	RegID)		/*!< ID of the non-volatile memory register to be used */	\
	I2CDRV_sendTwoByteInstruction_WW(										\
		X9241DRV_SLAVE_ADDRESS( DevID ),									\
		X9241DRV_INSTRUCTION( 0xD0, PotID, RegID ))

//- ----------------------------------------------------------------------------
//! \brief	Transfers the Wiper Counter Register (WCR) to a Data Register (a
//!			non-volatile memory cell) of a potentiometer.
//!
//! \pre	The I2C driver keeps the bus wires in their default/reset states.
//!
//!	Transfers the Wiper Counter Register (WCR) to a Data Register (a
//!	non-volatile memory cell) of a potentiometer.
//!
//!	The I2CDRV_sendTwoByteInstruction_WW() is called to perform the command.
//!
//!	\post	The I2C driver keeps the bus wires in their default/reset states.
//!
//!	\return	The number of bytes, which has been accepted.
//!	\retval	0		No byte was accepted. (The first was rejected.)
//!	\retval	1		Only the first byte was accepted. The second byte was
//!					rejected.
//!	\retval	2		Both bytes were accepted.
//- ----------------------------------------------------------------------------
#define X9241DRV_XFR_WCR_TO_DATA_REG(										\
	DevID,		/*!< ID of the device on the I2C bus */						\
	PotID,		/*!< ID of potentiometer to be used */						\
	RegID)		/*!< ID of the non-volatile memory register to be used */	\
	I2CDRV_sendTwoByteInstruction_WW(										\
		X9241DRV_SLAVE_ADDRESS( DevID ),									\
		X9241DRV_INSTRUCTION( 0xE0, PotID, RegID ))

//- ----------------------------------------------------------------------------
//! \brief	Transfers all the selected Data Registers (non-volatile memory
//!			cells) to the Wiper Counter Registers (WCR) of all the
//!			potentiometers in the selected device.
//!
//! \pre	The I2C driver keeps the bus wires in their default/reset states.
//!
//!	Transfers all the selected Data Registers (non-volatile memory cells) to the
//!	Wiper Counter Registers (WCR) of all the potentiometers in the selected
//!	device.
//!
//!	The I2CDRV_sendTwoByteInstruction_WW() is called to perform the command.
//!
//!	\post	The I2C driver keeps the bus wires in their default/reset states.
//!
//!	\return	The number of bytes, which has been accepted.
//!	\retval	0		No byte was accepted. (The first was rejected.)
//!	\retval	1		Only the first byte was accepted. The second byte was
//!					rejected.
//!	\retval	2		Both bytes were accepted.
//- ----------------------------------------------------------------------------
#define X9241DRV_GLOBAL_XFR_DATA_REG_TO_WCR(								\
	DevID,		/*!< ID of the device on the I2C bus */						\
	RegID)		/*!< ID of the non-volatile memory register to be used */	\
	I2CDRV_sendTwoByteInstruction_WW(										\
		X9241DRV_SLAVE_ADDRESS( DevID ),									\
		X9241DRV_INSTRUCTION( 0x10, 0, RegID ))

//- ----------------------------------------------------------------------------
//! \brief	Transfers the Wiper Counter Registers (WCR) of all the
//!			potentiometers to all the selected Data Registers (non-volatile
//!			memory cells) in the selected device.
//!
//! \pre	The I2C driver keeps the bus wires in their default/reset states.
//!
//!	Transfers the Wiper Counter Registers (WCR) of all the potentiometers to all
//!	the selected Data Registers (non-volatile memory cells) in the selected
//!	device.
//!
//!	The I2CDRV_sendTwoByteInstruction_WW() is called to perform the command.
//!
//!	\post	The I2C driver keeps the bus wires in their default/reset states.
//!
//!	\return	The number of bytes, which has been accepted.
//!	\retval	0		No byte was accepted. (The first was rejected.)
//!	\retval	1		Only the first byte was accepted. The second byte was
//!					rejected.
//!	\retval	2		Both bytes were accepted.
//- ----------------------------------------------------------------------------
#define X9241DRV_GLOBAL_XFR_WCR_TO_DATA_REG(								\
	DevID,		/*!< ID of the device on the I2C bus */						\
	RegID)		/*!< ID of the non-volatile memory register to be used */	\
	I2CDRV_sendTwoByteInstruction_WW(										\
		X9241DRV_SLAVE_ADDRESS( DevID ),									\
		X9241DRV_INSTRUCTION( 0x80, 0, RegID ))


/******************************************************************************\
* global typedef declarations
\******************************************************************************/


/******************************************************************************\
* global variable declarations
\******************************************************************************/


/******************************************************************************\
* global function declarations
\******************************************************************************/


/******************************************************************************\
* inline function declarations
\******************************************************************************/


/******************************************************************************\
* inline function definitions
\******************************************************************************/


#endif /* _BSL_X9241DRV_H_ */
/******************************************************************************\
* End of bsl_x9241drv.h
\******************************************************************************/

